==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/AutoscaleRecurrenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.AutoscaleRecurrenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Schedule-based autoscale request parameters
 * @property schedule Array of schedule-based autoscale rules
 * @property timeZone The time zone for the autoscale schedule times
 */
public data class AutoscaleRecurrenceArgs(
    public val schedule: Output<List<AutoscaleScheduleArgs>>? = null,
    public val timeZone: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.AutoscaleRecurrenceArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.AutoscaleRecurrenceArgs =
        com.pulumi.azurenative.hdinsight.inputs.AutoscaleRecurrenceArgs.builder()
            .schedule(
                schedule?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .timeZone(timeZone?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AutoscaleRecurrenceArgs].
 */
@PulumiTagMarker
public class AutoscaleRecurrenceArgsBuilder internal constructor() {
    private var schedule: Output<List<AutoscaleScheduleArgs>>? = null

    private var timeZone: Output<String>? = null

    /**
     * @param value Array of schedule-based autoscale rules
     */
    @JvmName("osoqyjxuqphvcgwa")
    public suspend fun schedule(`value`: Output<List<AutoscaleScheduleArgs>>) {
        this.schedule = value
    }

    @JvmName("poadtpipdjypmvoq")
    public suspend fun schedule(vararg values: Output<AutoscaleScheduleArgs>) {
        this.schedule = Output.all(values.asList())
    }

    /**
     * @param values Array of schedule-based autoscale rules
     */
    @JvmName("hgbooopisrxvbjnm")
    public suspend fun schedule(values: List<Output<AutoscaleScheduleArgs>>) {
        this.schedule = Output.all(values)
    }

    /**
     * @param value The time zone for the autoscale schedule times
     */
    @JvmName("cdqdrxjcrkltdkeu")
    public suspend fun timeZone(`value`: Output<String>) {
        this.timeZone = value
    }

    /**
     * @param value Array of schedule-based autoscale rules
     */
    @JvmName("badknaojbhcxfqqn")
    public suspend fun schedule(`value`: List<AutoscaleScheduleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schedule = mapped
    }

    /**
     * @param argument Array of schedule-based autoscale rules
     */
    @JvmName("cmpcqrigvrumhaxd")
    public suspend fun schedule(argument: List<suspend AutoscaleScheduleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AutoscaleScheduleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.schedule = mapped
    }

    /**
     * @param argument Array of schedule-based autoscale rules
     */
    @JvmName("usgiojvspcxrpclu")
    public suspend fun schedule(vararg argument: suspend AutoscaleScheduleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            AutoscaleScheduleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.schedule = mapped
    }

    /**
     * @param argument Array of schedule-based autoscale rules
     */
    @JvmName("ilejgqvgljbyhxlb")
    public suspend fun schedule(argument: suspend AutoscaleScheduleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AutoscaleScheduleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.schedule = mapped
    }

    /**
     * @param values Array of schedule-based autoscale rules
     */
    @JvmName("hcbfukvjadycrilm")
    public suspend fun schedule(vararg values: AutoscaleScheduleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schedule = mapped
    }

    /**
     * @param value The time zone for the autoscale schedule times
     */
    @JvmName("pcyrsrktfsrqfsst")
    public suspend fun timeZone(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeZone = mapped
    }

    internal fun build(): AutoscaleRecurrenceArgs = AutoscaleRecurrenceArgs(
        schedule = schedule,
        timeZone = timeZone,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/AutoscaleRecurrenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.AutoscaleRecurrenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Schedule-based autoscale request parameters
 * @property schedule Array of schedule-based autoscale rules
 * @property timeZone The time zone for the autoscale schedule times
 */
public data class AutoscaleRecurrenceArgs(
    public val schedule: Output<List<AutoscaleScheduleArgs>>? = null,
    public val timeZone: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.AutoscaleRecurrenceArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.AutoscaleRecurrenceArgs =
        com.pulumi.azurenative.hdinsight.inputs.AutoscaleRecurrenceArgs.builder()
            .schedule(
                schedule?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .timeZone(timeZone?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AutoscaleRecurrenceArgs].
 */
@PulumiTagMarker
public class AutoscaleRecurrenceArgsBuilder internal constructor() {
    private var schedule: Output<List<AutoscaleScheduleArgs>>? = null

    private var timeZone: Output<String>? = null

    /**
     * @param value Array of schedule-based autoscale rules
     */
    @JvmName("motgdltevsmdxnyy")
    public suspend fun schedule(`value`: Output<List<AutoscaleScheduleArgs>>) {
        this.schedule = value
    }

    @JvmName("tfuecppvheptoati")
    public suspend fun schedule(vararg values: Output<AutoscaleScheduleArgs>) {
        this.schedule = Output.all(values.asList())
    }

    /**
     * @param values Array of schedule-based autoscale rules
     */
    @JvmName("xlghtypnniictmse")
    public suspend fun schedule(values: List<Output<AutoscaleScheduleArgs>>) {
        this.schedule = Output.all(values)
    }

    /**
     * @param value The time zone for the autoscale schedule times
     */
    @JvmName("rttwrqnpdiyqcssy")
    public suspend fun timeZone(`value`: Output<String>) {
        this.timeZone = value
    }

    /**
     * @param value Array of schedule-based autoscale rules
     */
    @JvmName("liqasfaqcfuhswta")
    public suspend fun schedule(`value`: List<AutoscaleScheduleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schedule = mapped
    }

    /**
     * @param argument Array of schedule-based autoscale rules
     */
    @JvmName("xloxgejlfmgjxuxt")
    public suspend fun schedule(argument: List<suspend AutoscaleScheduleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AutoscaleScheduleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.schedule = mapped
    }

    /**
     * @param argument Array of schedule-based autoscale rules
     */
    @JvmName("pffcccyatepdodkh")
    public suspend fun schedule(vararg argument: suspend AutoscaleScheduleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            AutoscaleScheduleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.schedule = mapped
    }

    /**
     * @param argument Array of schedule-based autoscale rules
     */
    @JvmName("grfxdxgnowidnewf")
    public suspend fun schedule(argument: suspend AutoscaleScheduleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AutoscaleScheduleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.schedule = mapped
    }

    /**
     * @param values Array of schedule-based autoscale rules
     */
    @JvmName("cwuesqnfucwfqovx")
    public suspend fun schedule(vararg values: AutoscaleScheduleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schedule = mapped
    }

    /**
     * @param value The time zone for the autoscale schedule times
     */
    @JvmName("iuoghifhryihstla")
    public suspend fun timeZone(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeZone = mapped
    }

    internal fun build(): AutoscaleRecurrenceArgs = AutoscaleRecurrenceArgs(
        schedule = schedule,
        timeZone = timeZone,
    )
}
